# Green's Function report: \VAR{rpt_id}

\VAR{date}

## Table of Contents

\- for name, ph_str, arts in artefacts

#### Artefact Report: \VAR{name}

\- endfor \- for ttl, src, sen, img_data in chapters

#### \VAR{ttl}

\- for name, href, path in img_data \- if name != ''

\VAR{name}

\- endif \- endfor \- endfor

#### Appendix

\- for str_id, config, mdl_path, img_ttl in str_info \- if mdl_path != ''

Model configuration plots for \VAR{img_ttl}

\- endif

Model configuration for \VAR{str_id}

\- endfor

\- for name, ph_str, arts in artefacts

## Artefact Report: \VAR{name}

The artefact report is created by finding the maximum amplitude before and after a certain tabulated phase (after filtering without demeaning) for each trace, and then reports only the maximum value per source/senors array. The phase search string for this store was: \VAR{ph_str}.

Trace information | Aretefact maximum-ratio
--- | ---
\- for ttl, clr, rat in arts
\- if rat == '' \VAR{ttl} \- else | \VAR{ttl} \- endif | \VAR{rat}
\- endfor

\- endfor \- for ttl, src, sen, img_data in chapters

## \VAR{ttl}

%%This is the start of the chapter, so add text if wanted here to explain %% the plots or error of plots. This will be printed once per source- %% sensor setup. Below is the dump of the source and sensor properties.

Source information | Sensor array information
--- | ---
    \VAR{src}
    \VAR{sen}

\- for name, href, path in img_data
\- endfor

\- endfor

## Appendix

\- for str_id, config, mdl_path, img_ttl in str_info \- if mdl_path != ''

\- endif

### Model configuration: \VAR{str_id}

    \VAR{config}

\- endfor